@@ -12,25 +12,22 @@ from web_foundation.app.events.metrics import NewMetricEvent
 from web_foundation.app.infrastructure.metrics.exporter import Metric, MetricExporter
 from web_foundation.app.infrastructure.metrics.formatter import GenMetricFormatter
 from web_foundation.kernel import IChannel
+from web_foundation import settings
 
 
 class MetricsMixin:
     _metrics: List[Metric]
     _channel: IChannel
 
-    class MetricsEnabled:
-        pass
-
     def _reg_metrics(self):
         pass
 
     async def give_metric(self, metric: Metric):
-        if not hasattr(self, "MetricsEnabled"):
-            raise AttributeError("Please specify MetricsEnabled class in worker")
-        if metric.name not in vars(self.MetricsEnabled):
+        if settings.METRICS.get(metric.name):
+            asyncio.create_task(self._channel.produce(NewMetricEvent(metric)))
+        else:
             if settings.DEBUG:
-                logger.debug(f"Metric not found in MetricsEnabled {metric}")
-        asyncio.create_task(self._channel.produce(NewMetricEvent(metric)))
+                logger.debug(f"Metric({metric.name}) not enable in settings.METRIC")
 
 
 class ApiMetricsMixin(MetricsMixin):
